@@ -33,14 +33,14 @@ def main( argv ):
             creater = MakeFileCreater()
             return creater.createMakefile( argv )
         elif argv[1:2] == ['help']:
-            return help( argv )
+            return setup_help( argv )
         else:
-            return help( argv )
+            return setup_help( argv )
     except SetupError, e:
         print 'Error:',str(e)
         return 1
 
-def help( argv ):
+def setup_help( argv ):
     basename = os.path.basename( argv[0] )
     print '''
 
@@ -137,13 +137,28 @@ class MakeFileCreater:
         for flag in py_cflags_python_list:
             if flag.startswith( '-D' ):
                 py_cflags_list.append( flag )
+            if flag.startswith( '-O' ) or flag.startswith( '-f' ) or flag.startswith( '-g' ):
+                py_cflags_list.append( flag )
+
+        # add platform specific defines
+        if self.is_mac_os_x:
+            py_cflags_list.append( '-DDARWIN' )
 
         # get user supplied defines
         for arg in argv:
             if arg.startswith( '--define=' ):
                 py_cflags_list.append( '-D%s' % arg[len('--define-'):] )
 
+        # name of the module including the python version to help
+        # ensure that only a matching _pysvn.so for the version of
+        # python is imported
+        py_cflags_list.append( '-Dinit_pysvn=init_pysvn_%d_%d' % sys.version_info[:2] )
+        py_cflags_list.append( '-Dinit_pysvn_d=init_pysvn_%d_%d_d' % sys.version_info[:2] )
+
         template_values = {
+#            'pysvn_module_name': '_pysvn_%d_%d' % sys.version_info[:2],
+            'pysvn_module_name': '_pysvn',
+
             # python executable
             'python_exe':       sys.executable,
 
@@ -217,13 +232,17 @@ class MakeFileCreater:
                 else:
                     template_values['python_exp'] = 'python.exp'
             makefile.write( self.makefile_template_aix % template_values )
+        elif sys.platform.startswith('linux'):
+            if self.verbose:
+                print 'Info: Using Linux makefile template'
+            makefile.write( self.makefile_template_linux % template_values )
         else:
             if self.verbose:
                 print 'Info: Using unix makefile template'
             makefile.write( self.makefile_template % template_values )
 
         f = file( 'pysvn_common.mak', 'r' )
-        makefile.write( f.read() )
+        makefile.write( f.read() % template_values )
         f.close()
         makefile.close()
 
@@ -261,6 +280,27 @@ LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
 -lsvn_diff-1 \
+-lsvn_repos-1 \
+ -lcom_err -lresolv -lexpat -lneon
+
+#include pysvn_common.mak
+'''
+
+    makefile_template_linux = '''#
+#	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_linux --
+#
+PYTHON=%(python_exe)s
+SVN_INCLUDE=%(svn_include)s
+CCC=g++ -c
+CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
+CC=gcc -c
+CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
+PYCXX=%(pycxx_dir)s
+LDSHARED=g++ -shared %(debug_cflags)s
+LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
+-lsvn_client-1 \
+-lsvn_diff-1 \
 -lsvn_repos-1 `apr-config --link-ld --libs`
 
 #include pysvn_common.mak
@@ -299,6 +339,7 @@ LDLIBS=-L%(svn_lib_dir)s \
 -lexpat          \
 -lintl           \
 -lpthread        \
+-lz              \
 -Wl,-bI:%(python_exp)s
 
 #include pysvn_common.mak
@@ -414,7 +455,7 @@ LDLIBS= \
                     'PyCXX include',
                     '--pycxx-dir=',
                     None,
-                    [   '../Import/pycxx-5.3.6'],
+                    [   '../Import/pycxx-5.4.0'],
                     'cxxsupport.cxx' )
 
     def find_svn_inc( self, argv ):
@@ -454,6 +495,18 @@ LDLIBS= \
     def find_apr_inc( self, argv ):
         last_exception = None
         for apr_ver in ['apr-1.0', 'apr-1', 'apr-0']:
+            try:
+                return self.find_dir( argv,
+                    'APR include',
+                    '--apr-inc-dir=',
+                    'include/%s' % apr_ver,
+                    [
+                    ],
+                    'apr.h' )
+            except SetupError:
+                pass
+
+        for apr_ver in ['apr-1', 'apr-0']:
             try:
                 return self.find_dir( argv,
                     'APR include',
@@ -477,6 +530,19 @@ LDLIBS= \
 
     def find_apr_lib( self, argv ):
         last_exception = None
+        for apr_libname, self.lib_apr in [
+                            (self.is_mac_os_x and 'libapr-1.dylib' or 'libapr-1.so', 'apr-1'),
+                            (self.is_mac_os_x and 'libapr-0.dylib' or 'libapr-0.so', 'apr-0')]:
+            try:
+                return self.find_dir( argv,
+                    'APR library',
+                    '--apr-lib-dir=',
+                    'lib',
+                    [],
+                    apr_libname )
+            except SetupError:
+                pass
+
         for apr_libname, self.lib_apr in [
                             (self.is_mac_os_x and 'libapr-1.dylib' or 'libapr-1.so', 'apr-1'),
                             (self.is_mac_os_x and 'libapr-0.dylib' or 'libapr-0.so', 'apr-0')]:
